@@ -13,7 +13,7 @@ use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
 use Path::Tiny;
 
-our $VERSION = 0.08;
+our $VERSION = 0.009;
 
 sub directory {
     my ($self, $options) = @_;
@@ -21,13 +21,12 @@ sub directory {
     my $dir  = path('.')->absolute;
     my $home = path($ENV{HOME});
     my $dir_display = "$dir";
-    $options->{dir_length} ||= 30;
 
     if ($home->subsumes($dir) ) {
         $dir_display =~ s/$home/~/xms;
     }
-    if (length $dir_display > $options->{dir_length}) {
-        $dir_display = '...' . substr $dir_display, -$options->{dir_length}, $options->{dir_length};
+    if (length $dir_display > 20) {
+        $dir_display = '...' . substr $dir_display, -20, 20;
     }
     if ($options->{abreviate}) {
         $dir_display =~ s{/([^/])[^/]+/}{/$1/}g;
@@ -112,7 +111,7 @@ App::PS1::Plugin::Directory - Current directory information
 
 =head1 VERSION
 
-This documentation refers to App::PS1::Plugin::Directory version 0.08.
+This documentation refers to App::PS1::Plugin::Directory version 0.009.
 
 =head1 SYNOPSIS
 
